==> eam-wshub-proxyclient-11.6-1-sources.jar: net/datastream/schemas/mp_fields/TAB_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour TAB_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="TAB_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TABID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SYSTEMPERMISSIONS" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}USERGROUPPERMISSIONS" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SYSREQUIRED" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}HIDEMENU" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="SEQUENCENO" type="{http://www.w3.org/2001/XMLSchema}long" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "TAB_Type", propOrder = {
    "tabid",
    "systempermissions",
    "usergrouppermissions",
    "sysrequired",
    "hidemenu"
})
public class TAB_Type {

    @XmlElement(name = "TABID", required = true)
    protected TABID_Type tabid;
    @XmlElement(name = "SYSTEMPERMISSIONS")
    protected PERMISSIONS_Type systempermissions;
    @XmlElement(name = "USERGROUPPERMISSIONS")
    protected PERMISSIONS_Type usergrouppermissions;
    @XmlElement(name = "SYSREQUIRED")
    protected String sysrequired;
    @XmlElement(name = "HIDEMENU")
    protected String hidemenu;
    @XmlAttribute(name = "SEQUENCENO")
    protected Long sequenceno;

    /**
     * Obtient la valeur de la propriété tabid.
     * 
     * @return
     *     possible object is
     *     {@link TABID_Type }
     *     
     */
    public TABID_Type getTABID() {
        return tabid;
    }

    /**
     * Définit la valeur de la propriété tabid.
     * 
     * @param value
     *     allowed object is
     *     {@link TABID_Type }
     *     
     */
    public void setTABID(TABID_Type value) {
        this.tabid = value;
    }

    /**
     * Obtient la valeur de la propriété systempermissions.
     * 
     * @return
     *     possible object is
     *     {@link PERMISSIONS_Type }
     *     
     */
    public PERMISSIONS_Type getSYSTEMPERMISSIONS() {
        return systempermissions;
    }

    /**
     * Définit la valeur de la propriété systempermissions.
     * 
     * @param value
     *     allowed object is
     *     {@link PERMISSIONS_Type }
     *     
     */
    public void setSYSTEMPERMISSIONS(PERMISSIONS_Type value) {
        this.systempermissions = value;
    }

    /**
     * Obtient la valeur de la propriété usergrouppermissions.
     * 
     * @return
     *     possible object is
     *     {@link PERMISSIONS_Type }
     *     
     */
    public PERMISSIONS_Type getUSERGROUPPERMISSIONS() {
        return usergrouppermissions;
    }

    /**
     * Définit la valeur de la propriété usergrouppermissions.
     * 
     * @param value
     *     allowed object is
     *     {@link PERMISSIONS_Type }
     *     
     */
    public void setUSERGROUPPERMISSIONS(PERMISSIONS_Type value) {
        this.usergrouppermissions = value;
    }

    /**
     * Obtient la valeur de la propriété sysrequired.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSYSREQUIRED() {
        return sysrequired;
    }

    /**
     * Définit la valeur de la propriété sysrequired.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSYSREQUIRED(String value) {
        this.sysrequired = value;
    }

    /**
     * Obtient la valeur de la propriété hidemenu.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getHIDEMENU() {
        return hidemenu;
    }

    /**
     * Définit la valeur de la propriété hidemenu.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setHIDEMENU(String value) {
        this.hidemenu = value;
    }

    /**
     * Obtient la valeur de la propriété sequenceno.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getSEQUENCENO() {
        return sequenceno;
    }

    /**
     * Définit la valeur de la propriété sequenceno.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setSEQUENCENO(Long value) {
        this.sequenceno = value;
    }

}

==> eam-wshub-proxyclient-11.7-2-sources.jar: net/datastream/schemas/mp_fields/TAB_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for TAB_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="TAB_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TABID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SYSTEMPERMISSIONS" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}USERGROUPPERMISSIONS" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SYSREQUIRED" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}HIDEMENU" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="SEQUENCENO" type="{http://www.w3.org/2001/XMLSchema}long" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "TAB_Type", propOrder = {
    "tabid",
    "systempermissions",
    "usergrouppermissions",
    "sysrequired",
    "hidemenu"
})
public class TAB_Type {

    @XmlElement(name = "TABID", required = true)
    protected TABID_Type tabid;
    @XmlElement(name = "SYSTEMPERMISSIONS")
    protected PERMISSIONS_Type systempermissions;
    @XmlElement(name = "USERGROUPPERMISSIONS")
    protected PERMISSIONS_Type usergrouppermissions;
    @XmlElement(name = "SYSREQUIRED")
    protected String sysrequired;
    @XmlElement(name = "HIDEMENU")
    protected String hidemenu;
    @XmlAttribute(name = "SEQUENCENO")
    protected Long sequenceno;

    /**
     * Gets the value of the tabid property.
     * 
     * @return
     *     possible object is
     *     {@link TABID_Type }
     *     
     */
    public TABID_Type getTABID() {
        return tabid;
    }

    /**
     * Sets the value of the tabid property.
     * 
     * @param value
     *     allowed object is
     *     {@link TABID_Type }
     *     
     */
    public void setTABID(TABID_Type value) {
        this.tabid = value;
    }

    /**
     * Gets the value of the systempermissions property.
     * 
     * @return
     *     possible object is
     *     {@link PERMISSIONS_Type }
     *     
     */
    public PERMISSIONS_Type getSYSTEMPERMISSIONS() {
        return systempermissions;
    }

    /**
     * Sets the value of the systempermissions property.
     * 
     * @param value
     *     allowed object is
     *     {@link PERMISSIONS_Type }
     *     
     */
    public void setSYSTEMPERMISSIONS(PERMISSIONS_Type value) {
        this.systempermissions = value;
    }

    /**
     * Gets the value of the usergrouppermissions property.
     * 
     * @return
     *     possible object is
     *     {@link PERMISSIONS_Type }
     *     
     */
    public PERMISSIONS_Type getUSERGROUPPERMISSIONS() {
        return usergrouppermissions;
    }

    /**
     * Sets the value of the usergrouppermissions property.
     * 
     * @param value
     *     allowed object is
     *     {@link PERMISSIONS_Type }
     *     
     */
    public void setUSERGROUPPERMISSIONS(PERMISSIONS_Type value) {
        this.usergrouppermissions = value;
    }

    /**
     * Gets the value of the sysrequired property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSYSREQUIRED() {
        return sysrequired;
    }

    /**
     * Sets the value of the sysrequired property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSYSREQUIRED(String value) {
        this.sysrequired = value;
    }

    /**
     * Gets the value of the hidemenu property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getHIDEMENU() {
        return hidemenu;
    }

    /**
     * Sets the value of the hidemenu property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setHIDEMENU(String value) {
        this.hidemenu = value;
    }

    /**
     * Gets the value of the sequenceno property.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getSEQUENCENO() {
        return sequenceno;
    }

    /**
     * Sets the value of the sequenceno property.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setSEQUENCENO(Long value) {
        this.sequenceno = value;
    }

}
